<?php

namespace Drupal\sdc_library_paragraphs\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the SDC Library Paragraphs entity.
 *
 * @todo Should we have a universal SDC Library entity with paragraphs bundle?
 *
 * @ContentEntityType(
 *   id = "sdc_library_paragraphs",
 *   label = @Translation("SDC Library Paragraphs"),
 *   label_collection = @Translation("SDC Library Paragraphs"),
 *   label_singular = @Translation("SDC Library Paragraph"),
 *   label_plural = @Translation("SDC Library Paragraphs"),
 *   label_count = @PluralTranslation(
 *     singular = "@count SDC Library Paragraph",
 *     plural = "@count SDC Library Paragraphs",
 *   ),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\sdc_library_paragraphs\SdcLibraryParagraphsListBuilder",
 *     "form" = {
 *       "default" = "Drupal\sdc_library_paragraphs\SdcLibraryParagraphsForm",
 *     },
 *     "route_provider" = {
 *       "default" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   admin_permission = "use sdc library",
 *   base_table = "sdc_library_paragraphs",
 *   translatable = FALSE,
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "title" = "title",
 *     "langcode" = "langcode",
 *   },
 *   links = {
 *     "canonical" = "/sdc_library_paragraphs/{sdc_library_paragraphs}",
 *     "collection" = "/admin/content/sdc_library_paragraphs",
 *     "edit-form" = "/sdc_library_paragraphs/{sdc_library_paragraphs}/edit",
 *     "delete-form" = "/sdc_library_paragraphs/{sdc_library_paragraphs}/delete",
 *   },
 *   field_ui_base_route = "entity.sdc_library_paragraphs.admin_form"
 * )
 */
class SdcLibraryParagraphs extends ContentEntityBase implements ContentEntityInterface {

  /**
   * Paragraphs are generally within entities that have a getType() method.
   *
   * Adding this avoids a WSOD in case something akin to $parent->getType() is
   * called somewhere, like in a preprocess.
   */
  public function getType() {
    return 'sdc_library_paragraphs';
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['title'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setRequired(TRUE)
      ->setTranslatable(FALSE)
      ->setRevisionable(FALSE)
      ->setDefaultValue('SDC Library Paragraphs Entity Title')
      ->setSetting('max_length', 255)
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    // Primary key.
    $fields['id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the SDC Library Paragraphs entity.'))
      ->setReadOnly(TRUE);

    // Standard "uuid" field for entity.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the SDC Library Paragraphs entity.'))
      ->setReadOnly(TRUE);

    // Standard "created" field for entity.
    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The created timestamp.'))
      ->setReadOnly(TRUE);

    $fields['langcode']->setLabel(t('Language code'))
      ->setDescription(t('The language code.'))
      ->setReadOnly(TRUE)
      ->setDisplayOptions('form', ['region' => 'hidden']);

    $fields['field_sdc_referenced_paragraph'] = BaseFieldDefinition::create('entity_reference_revisions')
      ->setLabel(t('Referenced Paragraph'))
      ->setSetting('target_type', 'paragraph')
      ->setSetting('handler', 'default')
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'entity_reference_revisions_entity_view',
        'weight' => 0,
      ])
      ->setDisplayOptions('form', [
        'type' => 'paragraphs',
        'weight' => 0,
      ])
      ->setRequired(FALSE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setCardinality(1);

    return $fields;
  }

}
