<?php

namespace Drupal\sdc_library_paragraphs;

/**
 * Provides an interface for the SDC Library Paragraphs manager.
 */
interface ParagraphsManagerInterface {

  /**
   * Returns the render array of the specified SDC Paragraphs entity.
   *
   * @param mixed $sdcid
   *   The SDC Paragraphs entity ID.
   *
   * @return array
   *   The paragraph's render array.
   */
  public function getSdcEntityRenderArray(mixed $sdcid): array;

  /**
   * Returns the ID of an arbitrary paragraph from a specified bundle.
   *
   * @param string $paragraph_machine_name
   *   The paragraph bundle to target.
   *
   * @return int|null
   *   The paragraph's ID.
   */
  public function getArbitraryParagraphId(string $paragraph_machine_name = ''): ?int;

  /**
   * Returns the render array of an arbitrary paragraph ID.
   *
   * @param int $paragraph_target_id
   *   The paragraph ID to use.
   *
   * @return array
   *   The paragraph's render array.
   */
  public function getSpecificParagraphRenderArray(int $paragraph_target_id): array;

  /**
   * Returns the paragraph machine name being used by active component.
   *
   * @return string|null
   *   The paragraph's machine name or null.
   */
  public function getParagraphMachineNameFromActiveComponent(): ?string;

  /**
   * Returns the active paragraph's render array.
   *
   * @return array
   *   The paragraph's render array.
   */
  public function renderComponent(): array;

  /**
   * Returns the paragraph form's render array.
   *
   * @return array
   *   The paragraph form's render array.
   */
  public function renderComponentForm(): array;

}
