<?php

namespace Drupal\sdc_library_paragraphs;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure SDC Library Paragraphs settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sdc_library_paragraphs_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'sdc_library_paragraphs.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('sdc_library_paragraphs.settings');

    // Settings for anonymous users.
    $form['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('SDC Library Paragraphs settings'),
      '#open' => TRUE,
    ];
    $form['settings']['enabled'] = [
      '#title' => $this->t('Enabled'),
      '#description' => $this->t('Defaults to enabled. Disabling returns control to the the original SDC Library form instead of the form provided by the Paragraphs module.'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('enabled') ?? 1,
    ];
    $form['settings']['prefill'] = [
      '#title' => $this->t('Prefill using Paragraphs Library content'),
      '#description' => $this->t('Defaults to enabled. This is a courtesy setting for sites using reusable Paragraphs content by way of the Paragraphs Library module.'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('prefill') ?? 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('sdc_library_paragraphs.settings')
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('prefill', $form_state->getValue('prefill'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
